==> osx-9.3.1-en-download.zip: osx-9.3.1-en/webhelp/osx-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database entireaccess
//
//	Copyright (c) 2016-2023 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var entireaccess = {
    baseurls: ["../"],
    varname: "entireaccess",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "osx/overview.htm", title: "Entire Access for UNIX and Windows",
              tree: [
                  { url: "osx/whatsnew.htm", title: "What is New with this Version?" },
                  { url: "osx/how_osx_works.htm", title: "How Entire Access Works" },
                  { url: "osx/inst_entire_access.htm", title: "Prerequisite for Installing the Entire Access Server" },
                  { url: "osx/inst_server_unix.htm", title: "Installing a Server under UNIX" },
                  { url: "osx/inst_server_win.htm", title: "Installing a Server under Windows" },
                  { url: "osx/inst_client_unix.htm", title: "Installing a Client under UNIX" },
                  { url: "osx/inst_client_win.htm", title: "Installing a Client under Windows" },
                  { url: "osx/def_data_sources_to_nat.htm", title: "Defining Data Sources to Natural" },
                  { url: "osx/startup_win.htm", title: "Start-Up Procedures under Windows" },
                  { url: "osx/using_osx_service_win.htm", title: "Using Entire Access as Service under Windows" },
                  { url: "osx/uid_password.htm", title: "Supplying User ID and Password" },
                  { url: "osx/nat_with_osx.htm", title: "Using Natural with Entire Access" },
                  { url: "osx/error_diagnosis.htm", title: "Traces for Error Diagnosis" },
                  { url: "osx/osx_ssl.htm", title: "Entire Access and SSL" },
              ]
            },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: entireaccess });

==> osx-9.3.2-en-download.zip: osx-9.3.2-en/webhelp/osx-webhelp/navig/contents.js <==
//
//	FindinSite-CD-JS-HelpIndex database entireaccess
//
//	Copyright (c) 2016-2024 Software AG, Darmstadt, Germany and/or Software AG USA Inc., Reston, VA, USA
//
var entireaccess = {
    baseurls: ["../"],
    varname: "entireaccess",
        tree: [
            { url: "about/about.htm", title: "About this Documentation",
              tree: [
                  { url: "about/document_conventions.htm", title: "Document Conventions" },
                  { url: "about/online_information.htm", title: "Online Information and Support" },
                  { url: "about/data_protection.htm", title: "Data Protection" },
              ]
            },
            { url: "osx/overview.htm", title: "Entire Access for Linux and Windows",
              tree: [
                  { url: "osx/whatsnew.htm", title: "What is New with this Version?" },
                  { url: "osx/how_osx_works.htm", title: "How Entire Access Works" },
                  { url: "osx/inst_entire_access.htm", title: "Prerequisite for Installing the Entire Access Server" },
                  { url: "osx/inst_server_unix.htm", title: "Installing a Server under Linux" },
                  { url: "osx/inst_server_win.htm", title: "Installing a Server under Windows" },
                  { url: "osx/inst_client_unix.htm", title: "Installing a Client under Linux" },
                  { url: "osx/inst_client_win.htm", title: "Installing a Client under Windows" },
                  { url: "osx/def_data_sources_to_nat.htm", title: "Defining Data Sources to Natural" },
                  { url: "osx/startup_win.htm", title: "Start-Up Procedures under Windows" },
                  { url: "osx/using_osx_service_win.htm", title: "Using Entire Access as Service under Windows" },
                  { url: "osx/uid_password.htm", title: "Supplying User ID and Password" },
                  { url: "osx/nat_with_osx.htm", title: "Using Natural with Entire Access" },
                  { url: "osx/error_diagnosis.htm", title: "Traces for Error Diagnosis" },
                  { url: "osx/osx_ssl.htm", title: "Entire Access and SSL" },
              ]
            },
            { url: "general/legal.htm", title: "Copyright" },
        ]
};

var mainProject = 1;

$.event.trigger({ type: "fishidbloaded", db: entireaccess });
